@@ -10,9 +10,13 @@ use base 'Dancer::Engine';
 # return: a string of $template's content processed with $tokens
 sub render { die "render not implemented" }
 
+sub default_tmpl_ext { "tt" };
+
 sub view {
     my ($self, $view) = @_;
-    $view .= ".tt" if $view !~ /\.tt$/;
+
+    my $def_tmpl_ext = $self->default_tmpl_ext();
+    $view .= ".$def_tmpl_ext" if $view !~ /\.${def_tmpl_ext}$/;
 
     my $app = Dancer::App->current;
     return path($app->setting('views'), $view);
@@ -22,7 +26,8 @@ sub layout {
     my ($self, $layout, $tokens, $content) = @_;
 
     my $app = Dancer::App->current;
-    $layout .= '.tt' if $layout !~ /\.tt/;
+    my $def_tmpl_ext = $self->default_tmpl_ext();
+    $layout .= ".$def_tmpl_ext" if $layout !~ /\.${def_tmpl_ext}$/;
     $layout = path($app->setting('views'), 'layouts', $layout);
 
     my $full_content =
